import axios from 'axios'
// import qs from 'qs'
axios.defaults.headers['Content-Type'] = 'application/json;charset=UTF-8'; 

// 后端地址
//const baseURL = 'http://192.168.30.83:8989'
const baseURL = 'https://base.exploring.cn/test-engine-user-center'
// const baseURL = 'https://base.exploring.cn/wecom-server'

// 创建 axios 实例
const api = axios.create({
  baseURL,
  proxy: false,
})

// 根据 userId 获取 user 信息
export const fetchUser = async (userId: string) => {
  const response = await api.get<UserResponse>('/api/qywx-proxy/user/get', {
    params: {
      userid: userId,
    }
  });

  return response.data
}

// 根据 externalUserId 获取 externalUser 信息
export const fetchExternalUser = async (externalUserId: string, cursor?: string) => {
  const response = await api.get<ExternalUserResponse>('/api/qywx-proxy/externalcontact/get', {
    params: {
      external_userid: externalUserId,
      cursor
    }
  })

  return response.data.external_contact
}

// 根据 externalChatId 获取 chat 信息
export const fetchExternalChat = async (externalChatId: string) => {
  const response = await api.get<ExternalChatResponse>('/api/qywx-proxy/externalcontact/groupchat/get', {
    params: {
      chat_id: externalChatId,
      need_name : 1
    }
  })

  return response.data.group_chat
}

// 根据 code 换取 userId，作为用户身份验证
export const fetchUserId = async (code: string) => {
  // const response = await api.get<AuthResponse>('/api/qywx-proxy/user/getuserinfo', {
    const response = await api.get('/user_center/getWxUserInfo', {
      params: {
        code
      }
    })
  return response.data.data;
}

// 获取签名
export const fetchSignatures = async () => {  
  const response = await api.get('/user_center/signatures', {
    params: {
      url: window.location.href.split("#")[0]
    }
  })
  // alert(window.location.href.split("#")[0])
// alert(JSON.stringify(response))
  return response.data.data;
}
// 获取客户信息
export const getBaseInfoByWxId = async (params:any) => {
  const response = await api.get('/user_center/getBaseInfoByWxId', {
    params
  })
// alert(JSON.stringify(response))
  return response.data;
}
// 查找用户信息
export const selectUserBase = async (params:any) => {
  const response = await api.get('/user_center/selectUserBase', {
    params
  })
  return response.data;
}
// 关联客户
export const linkData = async (params:any) => {
  const response = await api.get('/user_center/linkData', {
    params
  })
  return response.data;
}
// 取消关联客户
export const unlinkData = async (params:any) => {
  const response = await api.get('/user_center/unlinkData', {
    params
  })
  return response.data;
}
//获取标签
export const getWxLabel = async (params:any) => {
  const response = await api.get('/user_center/getWxLabel', {
    params
  })
  return response.data;
}
// 创建标签
export const addWxLabel = async (params:any) => {
  const response = await api.get('/user_center/addWxLabel', {
    params
  })
  return response.data;
}
// 删除
export const deleteWxLabel = async (data:any) => {
  const response = await api.post('/user_center/deleteWxLabel', data
  )
  return response.data;
}
// 更新用户信息
export const updateBaseInfoFromCompanyWx = async (data:any) => {
  const response = await api.post('/user_center/updateBaseInfoFromCompanyWx', data)
  return response.data;
}
// 获取订单信息
export const getOrderInfoByWxId = async (params:any) => {
  const response = await api.get('/user_center/getOrderInfoByWxId', {
    params
  })
  return response.data;
}
export default api
